@@ -10,6 +10,7 @@ from qdrant_client.http.models import models as m
 
 SetIntStr = Set[Union[int, str]]
 DictIntStrAny = Dict[Union[int, str], Any]
+file = None
 
 
 def generate_encoders_by_class_tuples(type_encoder_map: Dict[Any, Callable]) -> Dict[Callable, Tuple]:
@@ -152,9 +153,28 @@ class _CollectionsApi:
     def __init__(self, api_client: "Union[ApiClient, AsyncApiClient]"):
         self.api_client = api_client
 
+    def _build_for_collection_cluster_info(
+        self,
+        collection_name: str,
+    ):
+        """
+        Get cluster information for a collection
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        return self.api_client.request(
+            type_=m.InlineResponse2006,
+            method="GET",
+            url="/collections/{collection_name}/cluster",
+            path_params=path_params,
+        )
+
     def _build_for_create_collection(
         self,
         collection_name: str,
+        timeout: int = None,
         create_collection: m.CreateCollection = None,
     ):
         """
@@ -164,13 +184,18 @@ class _CollectionsApi:
             "collection_name": str(collection_name),
         }
 
+        query_params = {}
+        if timeout is not None:
+            query_params["timeout"] = str(timeout)
+
         body = jsonable_encoder(create_collection)
 
         return self.api_client.request(
-            type_=m.InlineResponse2001,
+            type_=m.InlineResponse2002,
             method="PUT",
             url="/collections/{collection_name}",
             path_params=path_params,
+            params=query_params,
             json=body,
         )
 
@@ -194,7 +219,7 @@ class _CollectionsApi:
         body = jsonable_encoder(create_field_index)
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="PUT",
             url="/collections/{collection_name}/index",
             path_params=path_params,
@@ -202,9 +227,28 @@ class _CollectionsApi:
             json=body,
         )
 
+    def _build_for_create_snapshot(
+        self,
+        collection_name: str,
+    ):
+        """
+        Create new snapshot for a collection
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        return self.api_client.request(
+            type_=m.InlineResponse2008,
+            method="POST",
+            url="/collections/{collection_name}/snapshots",
+            path_params=path_params,
+        )
+
     def _build_for_delete_collection(
         self,
         collection_name: str,
+        timeout: int = None,
     ):
         """
         Drop collection and all associated data
@@ -213,11 +257,16 @@ class _CollectionsApi:
             "collection_name": str(collection_name),
         }
 
+        query_params = {}
+        if timeout is not None:
+            query_params["timeout"] = str(timeout)
+
         return self.api_client.request(
-            type_=m.InlineResponse2001,
+            type_=m.InlineResponse2002,
             method="DELETE",
             url="/collections/{collection_name}",
             path_params=path_params,
+            params=query_params,
         )
 
     def _build_for_delete_field_index(
@@ -239,7 +288,7 @@ class _CollectionsApi:
             query_params["wait"] = str(wait).lower()
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="DELETE",
             url="/collections/{collection_name}/index/{field_name}",
             path_params=path_params,
@@ -258,7 +307,7 @@ class _CollectionsApi:
         }
 
         return self.api_client.request(
-            type_=m.InlineResponse2002,
+            type_=m.InlineResponse2004,
             method="GET",
             url="/collections/{collection_name}",
             path_params=path_params,
@@ -271,22 +320,68 @@ class _CollectionsApi:
         Get list name of all existing collections
         """
         return self.api_client.request(
-            type_=m.InlineResponse200,
+            type_=m.InlineResponse2003,
             method="GET",
             url="/collections",
         )
 
+    def _build_for_get_snapshot(
+        self,
+        collection_name: str,
+        snapshot_name: str,
+    ):
+        """
+        Download specified snapshot from a collection as a file
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+            "snapshot_name": str(snapshot_name),
+        }
+
+        return self.api_client.request(
+            type_=file,
+            method="GET",
+            url="/collections/{collection_name}/snapshots/{snapshot_name}",
+            path_params=path_params,
+        )
+
+    def _build_for_list_snapshots(
+        self,
+        collection_name: str,
+    ):
+        """
+        Get list of snapshots for a collection
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        return self.api_client.request(
+            type_=m.InlineResponse2007,
+            method="GET",
+            url="/collections/{collection_name}/snapshots",
+            path_params=path_params,
+        )
+
     def _build_for_update_aliases(
         self,
+        timeout: int = None,
         change_aliases_operation: m.ChangeAliasesOperation = None,
     ):
+        query_params = {}
+        if timeout is not None:
+            query_params["timeout"] = str(timeout)
+
         body = jsonable_encoder(change_aliases_operation)
 
-        return self.api_client.request(type_=m.InlineResponse2001, method="POST", url="/collections/aliases", json=body)
+        return self.api_client.request(
+            type_=m.InlineResponse2002, method="POST", url="/collections/aliases", params=query_params, json=body
+        )
 
     def _build_for_update_collection(
         self,
         collection_name: str,
+        timeout: int = None,
         update_collection: m.UpdateCollection = None,
     ):
         """
@@ -296,39 +391,71 @@ class _CollectionsApi:
             "collection_name": str(collection_name),
         }
 
+        query_params = {}
+        if timeout is not None:
+            query_params["timeout"] = str(timeout)
+
         body = jsonable_encoder(update_collection)
 
         return self.api_client.request(
-            type_=m.InlineResponse2001,
+            type_=m.InlineResponse2002,
             method="PATCH",
             url="/collections/{collection_name}",
             path_params=path_params,
+            params=query_params,
             json=body,
         )
 
-    def _build_for_update_collections(
+    def _build_for_update_collection_cluster(
         self,
-        collection_meta_operations: m.CollectionMetaOperations = None,
+        collection_name: str,
+        timeout: int = None,
+        cluster_operations: m.ClusterOperations = None,
     ):
-        """
-        Perform update, create, remove or alias change operations on collections
-        """
-        body = jsonable_encoder(collection_meta_operations)
+        path_params = {
+            "collection_name": str(collection_name),
+        }
 
-        return self.api_client.request(type_=m.InlineResponse2001, method="POST", url="/collections", json=body)
+        query_params = {}
+        if timeout is not None:
+            query_params["timeout"] = str(timeout)
+
+        body = jsonable_encoder(cluster_operations)
+
+        return self.api_client.request(
+            type_=m.InlineResponse2002,
+            method="POST",
+            url="/collections/{collection_name}/cluster",
+            path_params=path_params,
+            params=query_params,
+            json=body,
+        )
 
 
 class AsyncCollectionsApi(_CollectionsApi):
+    async def collection_cluster_info(
+        self,
+        collection_name: str,
+    ) -> m.InlineResponse2006:
+        """
+        Get cluster information for a collection
+        """
+        return await self._build_for_collection_cluster_info(
+            collection_name=collection_name,
+        )
+
     async def create_collection(
         self,
         collection_name: str,
+        timeout: int = None,
         create_collection: m.CreateCollection = None,
-    ) -> m.InlineResponse2001:
+    ) -> m.InlineResponse2002:
         """
         Create new collection with given parameters
         """
         return await self._build_for_create_collection(
             collection_name=collection_name,
+            timeout=timeout,
             create_collection=create_collection,
         )
 
@@ -337,7 +464,7 @@ class AsyncCollectionsApi(_CollectionsApi):
         collection_name: str,
         wait: bool = None,
         create_field_index: m.CreateFieldIndex = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Create index for field in collection
         """
@@ -347,15 +474,28 @@ class AsyncCollectionsApi(_CollectionsApi):
             create_field_index=create_field_index,
         )
 
+    async def create_snapshot(
+        self,
+        collection_name: str,
+    ) -> m.InlineResponse2008:
+        """
+        Create new snapshot for a collection
+        """
+        return await self._build_for_create_snapshot(
+            collection_name=collection_name,
+        )
+
     async def delete_collection(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2001:
+        timeout: int = None,
+    ) -> m.InlineResponse2002:
         """
         Drop collection and all associated data
         """
         return await self._build_for_delete_collection(
             collection_name=collection_name,
+            timeout=timeout,
         )
 
     async def delete_field_index(
@@ -363,7 +503,7 @@ class AsyncCollectionsApi(_CollectionsApi):
         collection_name: str,
         field_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Delete field index for collection
         """
@@ -376,7 +516,7 @@ class AsyncCollectionsApi(_CollectionsApi):
     async def get_collection(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2002:
+    ) -> m.InlineResponse2004:
         """
         Get detailed information about specified existing collection
         """
@@ -386,56 +526,98 @@ class AsyncCollectionsApi(_CollectionsApi):
 
     async def get_collections(
         self,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2003:
         """
         Get list name of all existing collections
         """
         return await self._build_for_get_collections()
 
+    async def get_snapshot(
+        self,
+        collection_name: str,
+        snapshot_name: str,
+    ) -> file:
+        """
+        Download specified snapshot from a collection as a file
+        """
+        return await self._build_for_get_snapshot(
+            collection_name=collection_name,
+            snapshot_name=snapshot_name,
+        )
+
+    async def list_snapshots(
+        self,
+        collection_name: str,
+    ) -> m.InlineResponse2007:
+        """
+        Get list of snapshots for a collection
+        """
+        return await self._build_for_list_snapshots(
+            collection_name=collection_name,
+        )
+
     async def update_aliases(
         self,
+        timeout: int = None,
         change_aliases_operation: m.ChangeAliasesOperation = None,
-    ) -> m.InlineResponse2001:
+    ) -> m.InlineResponse2002:
         return await self._build_for_update_aliases(
+            timeout=timeout,
             change_aliases_operation=change_aliases_operation,
         )
 
     async def update_collection(
         self,
         collection_name: str,
+        timeout: int = None,
         update_collection: m.UpdateCollection = None,
-    ) -> m.InlineResponse2001:
+    ) -> m.InlineResponse2002:
         """
         Update parameters of the existing collection
         """
         return await self._build_for_update_collection(
             collection_name=collection_name,
+            timeout=timeout,
             update_collection=update_collection,
         )
 
-    async def update_collections(
+    async def update_collection_cluster(
         self,
-        collection_meta_operations: m.CollectionMetaOperations = None,
-    ) -> m.InlineResponse2001:
-        """
-        Perform update, create, remove or alias change operations on collections
-        """
-        return await self._build_for_update_collections(
-            collection_meta_operations=collection_meta_operations,
+        collection_name: str,
+        timeout: int = None,
+        cluster_operations: m.ClusterOperations = None,
+    ) -> m.InlineResponse2002:
+        return await self._build_for_update_collection_cluster(
+            collection_name=collection_name,
+            timeout=timeout,
+            cluster_operations=cluster_operations,
         )
 
 
 class SyncCollectionsApi(_CollectionsApi):
+    def collection_cluster_info(
+        self,
+        collection_name: str,
+    ) -> m.InlineResponse2006:
+        """
+        Get cluster information for a collection
+        """
+        return self._build_for_collection_cluster_info(
+            collection_name=collection_name,
+        )
+
     def create_collection(
         self,
         collection_name: str,
+        timeout: int = None,
         create_collection: m.CreateCollection = None,
-    ) -> m.InlineResponse2001:
+    ) -> m.InlineResponse2002:
         """
         Create new collection with given parameters
         """
         return self._build_for_create_collection(
             collection_name=collection_name,
+            timeout=timeout,
             create_collection=create_collection,
         )
 
@@ -444,7 +626,7 @@ class SyncCollectionsApi(_CollectionsApi):
         collection_name: str,
         wait: bool = None,
         create_field_index: m.CreateFieldIndex = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Create index for field in collection
         """
@@ -454,15 +636,28 @@ class SyncCollectionsApi(_CollectionsApi):
             create_field_index=create_field_index,
         )
 
+    def create_snapshot(
+        self,
+        collection_name: str,
+    ) -> m.InlineResponse2008:
+        """
+        Create new snapshot for a collection
+        """
+        return self._build_for_create_snapshot(
+            collection_name=collection_name,
+        )
+
     def delete_collection(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2001:
+        timeout: int = None,
+    ) -> m.InlineResponse2002:
         """
         Drop collection and all associated data
         """
         return self._build_for_delete_collection(
             collection_name=collection_name,
+            timeout=timeout,
         )
 
     def delete_field_index(
@@ -470,7 +665,7 @@ class SyncCollectionsApi(_CollectionsApi):
         collection_name: str,
         field_name: str,
         wait: bool = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Delete field index for collection
         """
@@ -483,7 +678,7 @@ class SyncCollectionsApi(_CollectionsApi):
     def get_collection(
         self,
         collection_name: str,
-    ) -> m.InlineResponse2002:
+    ) -> m.InlineResponse2004:
         """
         Get detailed information about specified existing collection
         """
@@ -493,40 +688,69 @@ class SyncCollectionsApi(_CollectionsApi):
 
     def get_collections(
         self,
-    ) -> m.InlineResponse200:
+    ) -> m.InlineResponse2003:
         """
         Get list name of all existing collections
         """
         return self._build_for_get_collections()
 
+    def get_snapshot(
+        self,
+        collection_name: str,
+        snapshot_name: str,
+    ) -> file:
+        """
+        Download specified snapshot from a collection as a file
+        """
+        return self._build_for_get_snapshot(
+            collection_name=collection_name,
+            snapshot_name=snapshot_name,
+        )
+
+    def list_snapshots(
+        self,
+        collection_name: str,
+    ) -> m.InlineResponse2007:
+        """
+        Get list of snapshots for a collection
+        """
+        return self._build_for_list_snapshots(
+            collection_name=collection_name,
+        )
+
     def update_aliases(
         self,
+        timeout: int = None,
         change_aliases_operation: m.ChangeAliasesOperation = None,
-    ) -> m.InlineResponse2001:
+    ) -> m.InlineResponse2002:
         return self._build_for_update_aliases(
+            timeout=timeout,
             change_aliases_operation=change_aliases_operation,
         )
 
     def update_collection(
         self,
         collection_name: str,
+        timeout: int = None,
         update_collection: m.UpdateCollection = None,
-    ) -> m.InlineResponse2001:
+    ) -> m.InlineResponse2002:
         """
         Update parameters of the existing collection
         """
         return self._build_for_update_collection(
             collection_name=collection_name,
+            timeout=timeout,
             update_collection=update_collection,
         )
 
-    def update_collections(
+    def update_collection_cluster(
         self,
-        collection_meta_operations: m.CollectionMetaOperations = None,
-    ) -> m.InlineResponse2001:
-        """
-        Perform update, create, remove or alias change operations on collections
-        """
-        return self._build_for_update_collections(
-            collection_meta_operations=collection_meta_operations,
+        collection_name: str,
+        timeout: int = None,
+        cluster_operations: m.ClusterOperations = None,
+    ) -> m.InlineResponse2002:
+        return self._build_for_update_collection_cluster(
+            collection_name=collection_name,
+            timeout=timeout,
+            cluster_operations=cluster_operations,
         )
