@@ -10,6 +10,7 @@ from qdrant_client.http.models import models as m
 
 SetIntStr = Set[Union[int, str]]
 DictIntStrAny = Dict[Union[int, str], Any]
+file = None
 
 
 def generate_encoders_by_class_tuples(type_encoder_map: Dict[Any, Callable]) -> Dict[Callable, Tuple]:
@@ -172,7 +173,7 @@ class _PointsApi:
         body = jsonable_encoder(points_selector)
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="POST",
             url="/collections/{collection_name}/points/payload/clear",
             path_params=path_params,
@@ -180,6 +181,28 @@ class _PointsApi:
             json=body,
         )
 
+    def _build_for_count_points(
+        self,
+        collection_name: str,
+        count_request: m.CountRequest = None,
+    ):
+        """
+        Count points which matches given filtering condition
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        body = jsonable_encoder(count_request)
+
+        return self.api_client.request(
+            type_=m.InlineResponse20014,
+            method="POST",
+            url="/collections/{collection_name}/points/count",
+            path_params=path_params,
+            json=body,
+        )
+
     def _build_for_delete_payload(
         self,
         collection_name: str,
@@ -200,7 +223,7 @@ class _PointsApi:
         body = jsonable_encoder(delete_payload)
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="POST",
             url="/collections/{collection_name}/points/payload/delete",
             path_params=path_params,
@@ -228,7 +251,7 @@ class _PointsApi:
         body = jsonable_encoder(points_selector)
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="POST",
             url="/collections/{collection_name}/points/delete",
             path_params=path_params,
@@ -250,7 +273,7 @@ class _PointsApi:
         }
 
         return self.api_client.request(
-            type_=m.InlineResponse2007,
+            type_=m.InlineResponse2009,
             method="GET",
             url="/collections/{collection_name}/points/{id}",
             path_params=path_params,
@@ -271,13 +294,35 @@ class _PointsApi:
         body = jsonable_encoder(point_request)
 
         return self.api_client.request(
-            type_=m.InlineResponse2004,
+            type_=m.InlineResponse20010,
             method="POST",
             url="/collections/{collection_name}/points",
             path_params=path_params,
             json=body,
         )
 
+    def _build_for_recommend_batch_points(
+        self,
+        collection_name: str,
+        recommend_request_batch: m.RecommendRequestBatch = None,
+    ):
+        """
+        Look for the points which are closer to stored positive examples and at the same time further to negative examples.
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        body = jsonable_encoder(recommend_request_batch)
+
+        return self.api_client.request(
+            type_=m.InlineResponse20013,
+            method="POST",
+            url="/collections/{collection_name}/points/recommend/batch",
+            path_params=path_params,
+            json=body,
+        )
+
     def _build_for_recommend_points(
         self,
         collection_name: str,
@@ -293,7 +338,7 @@ class _PointsApi:
         body = jsonable_encoder(recommend_request)
 
         return self.api_client.request(
-            type_=m.InlineResponse2005,
+            type_=m.InlineResponse20012,
             method="POST",
             url="/collections/{collection_name}/points/recommend",
             path_params=path_params,
@@ -315,13 +360,35 @@ class _PointsApi:
         body = jsonable_encoder(scroll_request)
 
         return self.api_client.request(
-            type_=m.InlineResponse2006,
+            type_=m.InlineResponse20011,
             method="POST",
             url="/collections/{collection_name}/points/scroll",
             path_params=path_params,
             json=body,
         )
 
+    def _build_for_search_batch_points(
+        self,
+        collection_name: str,
+        search_request_batch: m.SearchRequestBatch = None,
+    ):
+        """
+        Retrieve by batch the closest points based on vector similarity and given filtering conditions
+        """
+        path_params = {
+            "collection_name": str(collection_name),
+        }
+
+        body = jsonable_encoder(search_request_batch)
+
+        return self.api_client.request(
+            type_=m.InlineResponse20013,
+            method="POST",
+            url="/collections/{collection_name}/points/search/batch",
+            path_params=path_params,
+            json=body,
+        )
+
     def _build_for_search_points(
         self,
         collection_name: str,
@@ -337,7 +404,7 @@ class _PointsApi:
         body = jsonable_encoder(search_request)
 
         return self.api_client.request(
-            type_=m.InlineResponse2005,
+            type_=m.InlineResponse20012,
             method="POST",
             url="/collections/{collection_name}/points/search",
             path_params=path_params,
@@ -364,7 +431,7 @@ class _PointsApi:
         body = jsonable_encoder(set_payload)
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="POST",
             url="/collections/{collection_name}/points/payload",
             path_params=path_params,
@@ -372,34 +439,6 @@ class _PointsApi:
             json=body,
         )
 
-    def _build_for_update_points(
-        self,
-        collection_name: str,
-        wait: bool = None,
-        collection_update_operations: m.CollectionUpdateOperations = None,
-    ):
-        """
-        Perform point update operation (vectors, payloads, indexes) in collection
-        """
-        path_params = {
-            "collection_name": str(collection_name),
-        }
-
-        query_params = {}
-        if wait is not None:
-            query_params["wait"] = str(wait).lower()
-
-        body = jsonable_encoder(collection_update_operations)
-
-        return self.api_client.request(
-            type_=m.InlineResponse2003,
-            method="POST",
-            url="/collections/{collection_name}",
-            path_params=path_params,
-            params=query_params,
-            json=body,
-        )
-
     def _build_for_upsert_points(
         self,
         collection_name: str,
@@ -420,7 +459,7 @@ class _PointsApi:
         body = jsonable_encoder(point_insert_operations)
 
         return self.api_client.request(
-            type_=m.InlineResponse2003,
+            type_=m.InlineResponse2005,
             method="PUT",
             url="/collections/{collection_name}/points",
             path_params=path_params,
@@ -435,7 +474,7 @@ class AsyncPointsApi(_PointsApi):
         collection_name: str,
         wait: bool = None,
         points_selector: m.PointsSelector = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Remove all payload for specified points
         """
@@ -445,12 +484,25 @@ class AsyncPointsApi(_PointsApi):
             points_selector=points_selector,
         )
 
+    async def count_points(
+        self,
+        collection_name: str,
+        count_request: m.CountRequest = None,
+    ) -> m.InlineResponse20014:
+        """
+        Count points which matches given filtering condition
+        """
+        return await self._build_for_count_points(
+            collection_name=collection_name,
+            count_request=count_request,
+        )
+
     async def delete_payload(
         self,
         collection_name: str,
         wait: bool = None,
         delete_payload: m.DeletePayload = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Delete specified key payload for points
         """
@@ -465,7 +517,7 @@ class AsyncPointsApi(_PointsApi):
         collection_name: str,
         wait: bool = None,
         points_selector: m.PointsSelector = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Delete points
         """
@@ -479,7 +531,7 @@ class AsyncPointsApi(_PointsApi):
         self,
         collection_name: str,
         id: m.ExtendedPointId,
-    ) -> m.InlineResponse2007:
+    ) -> m.InlineResponse2009:
         """
         Retrieve full information of single point by id
         """
@@ -492,7 +544,7 @@ class AsyncPointsApi(_PointsApi):
         self,
         collection_name: str,
         point_request: m.PointRequest = None,
-    ) -> m.InlineResponse2004:
+    ) -> m.InlineResponse20010:
         """
         Retrieve multiple points by specified IDs
         """
@@ -501,11 +553,24 @@ class AsyncPointsApi(_PointsApi):
             point_request=point_request,
         )
 
+    async def recommend_batch_points(
+        self,
+        collection_name: str,
+        recommend_request_batch: m.RecommendRequestBatch = None,
+    ) -> m.InlineResponse20013:
+        """
+        Look for the points which are closer to stored positive examples and at the same time further to negative examples.
+        """
+        return await self._build_for_recommend_batch_points(
+            collection_name=collection_name,
+            recommend_request_batch=recommend_request_batch,
+        )
+
     async def recommend_points(
         self,
         collection_name: str,
         recommend_request: m.RecommendRequest = None,
-    ) -> m.InlineResponse2005:
+    ) -> m.InlineResponse20012:
         """
         Look for the points which are closer to stored positive examples and at the same time further to negative examples.
         """
@@ -518,7 +583,7 @@ class AsyncPointsApi(_PointsApi):
         self,
         collection_name: str,
         scroll_request: m.ScrollRequest = None,
-    ) -> m.InlineResponse2006:
+    ) -> m.InlineResponse20011:
         """
         Scroll request - paginate over all points which matches given filtering condition
         """
@@ -527,11 +592,24 @@ class AsyncPointsApi(_PointsApi):
             scroll_request=scroll_request,
         )
 
+    async def search_batch_points(
+        self,
+        collection_name: str,
+        search_request_batch: m.SearchRequestBatch = None,
+    ) -> m.InlineResponse20013:
+        """
+        Retrieve by batch the closest points based on vector similarity and given filtering conditions
+        """
+        return await self._build_for_search_batch_points(
+            collection_name=collection_name,
+            search_request_batch=search_request_batch,
+        )
+
     async def search_points(
         self,
         collection_name: str,
         search_request: m.SearchRequest = None,
-    ) -> m.InlineResponse2005:
+    ) -> m.InlineResponse20012:
         """
         Retrieve closest points based on vector similarity and given filtering conditions
         """
@@ -545,7 +623,7 @@ class AsyncPointsApi(_PointsApi):
         collection_name: str,
         wait: bool = None,
         set_payload: m.SetPayload = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Set payload for points
         """
@@ -555,27 +633,12 @@ class AsyncPointsApi(_PointsApi):
             set_payload=set_payload,
         )
 
-    async def update_points(
-        self,
-        collection_name: str,
-        wait: bool = None,
-        collection_update_operations: m.CollectionUpdateOperations = None,
-    ) -> m.InlineResponse2003:
-        """
-        Perform point update operation (vectors, payloads, indexes) in collection
-        """
-        return await self._build_for_update_points(
-            collection_name=collection_name,
-            wait=wait,
-            collection_update_operations=collection_update_operations,
-        )
-
     async def upsert_points(
         self,
         collection_name: str,
         wait: bool = None,
         point_insert_operations: m.PointInsertOperations = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Perform insert + updates on points. If point with given ID already exists - it will be overwritten.
         """
@@ -592,7 +655,7 @@ class SyncPointsApi(_PointsApi):
         collection_name: str,
         wait: bool = None,
         points_selector: m.PointsSelector = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Remove all payload for specified points
         """
@@ -602,12 +665,25 @@ class SyncPointsApi(_PointsApi):
             points_selector=points_selector,
         )
 
+    def count_points(
+        self,
+        collection_name: str,
+        count_request: m.CountRequest = None,
+    ) -> m.InlineResponse20014:
+        """
+        Count points which matches given filtering condition
+        """
+        return self._build_for_count_points(
+            collection_name=collection_name,
+            count_request=count_request,
+        )
+
     def delete_payload(
         self,
         collection_name: str,
         wait: bool = None,
         delete_payload: m.DeletePayload = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Delete specified key payload for points
         """
@@ -622,7 +698,7 @@ class SyncPointsApi(_PointsApi):
         collection_name: str,
         wait: bool = None,
         points_selector: m.PointsSelector = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Delete points
         """
@@ -636,7 +712,7 @@ class SyncPointsApi(_PointsApi):
         self,
         collection_name: str,
         id: m.ExtendedPointId,
-    ) -> m.InlineResponse2007:
+    ) -> m.InlineResponse2009:
         """
         Retrieve full information of single point by id
         """
@@ -649,7 +725,7 @@ class SyncPointsApi(_PointsApi):
         self,
         collection_name: str,
         point_request: m.PointRequest = None,
-    ) -> m.InlineResponse2004:
+    ) -> m.InlineResponse20010:
         """
         Retrieve multiple points by specified IDs
         """
@@ -658,11 +734,24 @@ class SyncPointsApi(_PointsApi):
             point_request=point_request,
         )
 
+    def recommend_batch_points(
+        self,
+        collection_name: str,
+        recommend_request_batch: m.RecommendRequestBatch = None,
+    ) -> m.InlineResponse20013:
+        """
+        Look for the points which are closer to stored positive examples and at the same time further to negative examples.
+        """
+        return self._build_for_recommend_batch_points(
+            collection_name=collection_name,
+            recommend_request_batch=recommend_request_batch,
+        )
+
     def recommend_points(
         self,
         collection_name: str,
         recommend_request: m.RecommendRequest = None,
-    ) -> m.InlineResponse2005:
+    ) -> m.InlineResponse20012:
         """
         Look for the points which are closer to stored positive examples and at the same time further to negative examples.
         """
@@ -675,7 +764,7 @@ class SyncPointsApi(_PointsApi):
         self,
         collection_name: str,
         scroll_request: m.ScrollRequest = None,
-    ) -> m.InlineResponse2006:
+    ) -> m.InlineResponse20011:
         """
         Scroll request - paginate over all points which matches given filtering condition
         """
@@ -684,11 +773,24 @@ class SyncPointsApi(_PointsApi):
             scroll_request=scroll_request,
         )
 
+    def search_batch_points(
+        self,
+        collection_name: str,
+        search_request_batch: m.SearchRequestBatch = None,
+    ) -> m.InlineResponse20013:
+        """
+        Retrieve by batch the closest points based on vector similarity and given filtering conditions
+        """
+        return self._build_for_search_batch_points(
+            collection_name=collection_name,
+            search_request_batch=search_request_batch,
+        )
+
     def search_points(
         self,
         collection_name: str,
         search_request: m.SearchRequest = None,
-    ) -> m.InlineResponse2005:
+    ) -> m.InlineResponse20012:
         """
         Retrieve closest points based on vector similarity and given filtering conditions
         """
@@ -702,7 +804,7 @@ class SyncPointsApi(_PointsApi):
         collection_name: str,
         wait: bool = None,
         set_payload: m.SetPayload = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Set payload for points
         """
@@ -712,27 +814,12 @@ class SyncPointsApi(_PointsApi):
             set_payload=set_payload,
         )
 
-    def update_points(
-        self,
-        collection_name: str,
-        wait: bool = None,
-        collection_update_operations: m.CollectionUpdateOperations = None,
-    ) -> m.InlineResponse2003:
-        """
-        Perform point update operation (vectors, payloads, indexes) in collection
-        """
-        return self._build_for_update_points(
-            collection_name=collection_name,
-            wait=wait,
-            collection_update_operations=collection_update_operations,
-        )
-
     def upsert_points(
         self,
         collection_name: str,
         wait: bool = None,
         point_insert_operations: m.PointInsertOperations = None,
-    ) -> m.InlineResponse2003:
+    ) -> m.InlineResponse2005:
         """
         Perform insert + updates on points. If point with given ID already exists - it will be overwritten.
         """
